Learn R Programming

popsom (version 3.0.1)

map.accuracy: Estimated Topographical Accuracy

Description

Evaluate the topological quality of a SOM using the estimated topographical accuracy.

Usage

map.accuracy(map, k=50, conf.int = 0.95, verb=FALSE)

Arguments

map
an object of type 'map'.
k
number of samples to use in the computation of the estimated topographical accuracy (default=50)
conf.int
the confidence interval of the estimated topographical accuracy (default 95 percent).
verb
a switch controlling the structure of the output value (default=FALSE)

Value

A list with three components: 1) the value of the estimated topographical accuracy 2) the low value of the confidence interval 'conf.int' 3) the high value of the confidence interval. If verb=TRUE then map.accuracy will return a vector with the accuracies of the individual k samples.

References

"SOM Quality Measures: A Statistical Approach," Lutz Hamel, in preparation, 2015.

Examples

Run this code
data(iris)

## set data frame and labels
df <- subset(iris,select=-Species)
labels <- subset(iris,select=Species)

## build a map
m <- map.build(df, labels, xdim=15, ydim=10, train=1000)

## display estimated topographical accuracy of the map
map.accuracy(m)

Run the code above in your browser using DataLab