Learn R Programming

popsom (version 3.0.1)

map.convergence: Evaluate Map Convergence

Description

Evaluates the convergence of a map using a two-sample statistical test.

Usage

map.convergence(map, conf.int = 0.95, verb=FALSE)

Arguments

map
an object of type 'map'.
conf.int
the confidence interval of the convergence test (default 95 percent).
verb
a switch controlling the structure of the output value (default=FALSE)

Value

If the switch verb=TRUE then a vector of the individual feature convergence indices is returned.

References

"A Population Based Convergence Criterion for Self-Organizing Maps," Lutz Hamel and Benjamin Ott. Proceeding of the 2012 International Conference on Data Mining (DMIN'12), pp98-104, July 16-19, 2012, Las Vegas Nevada, USA.

Examples

Run this code
data(iris)

## set data frame and labels
df <- subset(iris,select=-Species)
labels <- subset(iris,select=Species)

## build a map
m <- map.build(df, labels, xdim=15, ydim=10, train=1000)

## display the convergence index of the map
map.convergence(m)

## display the convergence indices of the individual features
data.frame(names(df),map.convergence(m,verb=TRUE))

Run the code above in your browser using DataLab