Learn R Programming

popsom (version 3.0.1)

map.feature: Generate Enhanced Unified Distance Matrix For Feature

Description

Computes and displays the enhanced unified distance matrix for a feature of the training data.

Usage

map.feature(map, feature, explicit = FALSE, smoothing = 2)

Arguments

map
an object of type 'map'.
feature
an integer as the index of the feature.
explicit
controls the shape of the connected components.
smoothing
controls the smoothing level of the umat (NULL, 0, >0).

Examples

Run this code
data(iris)

## set data frame and labels
df <- subset(iris,select=-Species)
labels <- subset(iris,select=Species)

## build a map
m <- map.build(df, labels, xdim=15, ydim=10, train=1000)

## display the umat for the first feature of the map
map.feature(m, 1)

Run the code above in your browser using DataLab